from . import category, query

category = {
    "community": category.community,
    "events": category.events,
    "forsale": category.forsale,
    "gigs": category.gigs,
    "housing": category.housing,
    "jobs": category.jobs,
    "resumes": category.resumes,
}
