community = {
    "act": "activity partners",
    "ats": "artists",
    "kid": "childcare",
    "com": "general community",
    "grp": "groups",
    "vnn": "local news and views",
    "laf": "lost & found",
    "mis": "missed connections",
    "muc": "musicians",
    "pet": "pets",
    "pol": "politics",
    "rnr": "rants & raves",
    "rid": "rideshare",
    "vol": "volunteers",
}

events = {}

forsale = {
    "ata": "antiques",
    "ppa": "appliances",
    "ara": "arts & crafts",
    "sna": "atvs, utvs, snowmobiles",
    "pta": "auto parts",
    "wta": "auto wheels & tires",
    "ava": "aviation",
    "baa": "baby & kid stuff",
    "bar": "barter",
    "bip": "bicycle parts",
    "bia": "bicycles",
    "bpa": "boat parts & accessories",
    "boo": "boats",
    "bka": "books & magazines",
    "bfa": "business",
    "cta": "cars & trucks",
    "ema": "cds / dvds / vhs",
    "moa": "cell phones",
    "cla": "clothing & accessories",
    "cba": "collectibles",
    "syp": "computer parts",
    "sya": "computers",
    "ela": "electronics",
    "gra": "farm & garden",
    "zip": "free stuff",
    "fua": "furniture",
    "gms": "garage & moving sales",
    "foa": "general for sale",
    "haa": "health and beauty",
    "hva": "heavy equipment",
    "hsa": "household items",
    "jwa": "jewelry",
    "maa": "materials",
    "mpa": "motorcycle parts & accessories",
    "mca": "motorcycles/scooters",
    "msa": "musical instruments",
    "pha": "photo/video",
    "rva": "recreational vehicles",
    "sga": "sporting goods",
    "tia": "tickets",
    "tla": "tools",
    "taa": "toys & games",
    "tra": "trailers",
    "vga": "video gaming",
    "waa": "wanted",
}

gigs = {
    "cpg": "computer gigs",
    "crg": "creative gigs",
    "cwg": "crew gigs",
    "dmg": "domestic gigs",
    "evg": "event gigs",
    "lbg": "labor gigs",
    "tlg": "talent gigs",
    "wrg": "writing gigs",
}

housing = {
    "apa": "apartments / housing for rent",
    "swp": "housing swap",
    "off": "office & commercial",
    "prk": "parking & storage",
    "rea": "real estate",
    "roo": "rooms & shares",
    "sub": "sublets & temporary",
    "vac": "vacation rentals",
    "hou": "wanted: apts",
    "rew": "wanted: real estate",
    "sha": "wanted: room/share",
    "sbw": "wanted: sublet/temp",
}

jobs = {
    "acc": "accounting/finance",
    "ofc": "admin/office",
    "egr": "architect/engineer/cad",
    "med": "art/media/design",
    "bus": "business/mgmt",
    "csr": "customer service",
    "edu": "education/teaching",
    "etc": "et cetera",
    "fbh": "food/beverage/hospitality",
    "lab": "general labor",
    "gov": "government",
    "hea": "healthcare",
    "hum": "human resource",
    "lgl": "legal/paralegal",
    "mnu": "manufacturing",
    "mar": "marketing/advertising/pr",
    "npo": "nonprofit",
    "rej": "real estate",
    "ret": "retail/wholesale",
    "sls": "sales",
    "spa": "salon/spa/fitness",
    "sci": "science/biotech",
    "sec": "security",
    "trd": "skilled trades/artisan",
    "sof": "software/qa/dba/etc",
    "sad": "systems/networking",
    "tch": "technical support",
    "trp": "transportation",
    "tfr": "tv/film/video/radio",
    "web": "web/html/info design",
    "wri": "writing/editing",
}

resumes = {}
